summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_factory.h')
-rw-r--r--kig/objects/object_factory.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kig/objects/object_factory.h b/kig/objects/object_factory.h
index 30f080d9..f3a28d66 100644
--- a/kig/objects/object_factory.h
+++ b/kig/objects/object_factory.h
@@ -94,26 +94,26 @@ public:
ObjectHolder* locus( ObjectCalcer* a, ObjectCalcer* b ) const;
/**
* returns a label with text \p s at point \p c .. It ( and its parents )
* is calced already...
*/
ObjectHolder* label(
const TQString& s, const Coordinate& loc,
- bool needframe, const std::vector<ObjectCalcer*>& parents,
+ bool needframe, const std::vector<ObjectCalcer*>& tqparents,
const KigDocument& doc ) const;
ObjectTypeCalcer* labelCalcer(
const TQString& s, const Coordinate& loc,
- bool needframe, const std::vector<ObjectCalcer*>& parents,
+ bool needframe, const std::vector<ObjectCalcer*>& tqparents,
const KigDocument& doc ) const;
/**
* this one does the same as the above, only that the new label is
* attached to locationparent if it is non-null..
*/
ObjectTypeCalcer* attachedLabelCalcer(
- const TQString& s, ObjectCalcer* locationparent,
+ const TQString& s, ObjectCalcer* locationtqparent,
const Coordinate& loc, bool needframe,
- const std::vector<ObjectCalcer*>& parents,
+ const std::vector<ObjectCalcer*>& tqparents,
const KigDocument& doc ) const;
/**
* this has been added because it comes handy when redefining
@@ -121,13 +121,13 @@ public:
* attach point from the method above
*/
ObjectCalcer* getAttachPoint(
- ObjectCalcer* locationparent,
+ ObjectCalcer* locationtqparent,
const Coordinate& loc,
const KigDocument& doc ) const;
ObjectHolder* attachedLabel(
- const TQString& s, ObjectCalcer* locationparent,
+ const TQString& s, ObjectCalcer* locationtqparent,
const Coordinate& loc, bool needframe,
- const std::vector<ObjectCalcer*>& parents,
+ const std::vector<ObjectCalcer*>& tqparents,
const KigDocument& doc ) const;
/**
@@ -94,26 +94,26 @@ public:
ObjectHolder* locus( ObjectCalcer* a, ObjectCalcer* b ) const;
/**
- * returns a label with text \p s at point \p c .. It ( and its parents )
+ * returns a label with text \p s at point \p c .. It ( and its tqparents )
* is calced already...
*/
@@ -94,26 +94,26 @@ public:
/**
* this one does the same as the above, only that the new label is
- * attached to locationparent if it is non-null..
+ * attached to locationtqparent if it is non-null..
*/
ObjectTypeCalcer* attachedLabelCalcer(